@@ -7,3 +7,8 @@ def create_folder(dir_path):
     if not os.path.exists(dir_path):
         os.makedirs(dir_path)
     return True
+
+
+def title_with_actions(task):
+    """return task name task actions"""
+    return "%s => %s"% (task.name, str(task))
